clear all
version 12.1
use "Replication dataset JPP Franchino Mainenti.dta"
drop if number_unlawfulaid==.

*** Declare data to be panel
xtset member_state year, yearly

* Descriptive statistics
xtsum number_unlawfulaid number_totalaid
hist number_unlawfulaid, discrete freq scheme(s1mono)

* Note: The unconditional mean of number_unlawfulaid is much lower than its variance.

* Correlations
pwcorr number_unlawfulaid number_totalaid y_num3 , sig

*** Analysis on Number of unlawful measures 2001-2012 (DV: number unlawful grants without crisis measure)

************ Hypothesis 1: the lower the district magnitude, the higher the likelihood of adopting unlawful measures
*(Model 1 in comparing model.do)
* Model 1: District magnitude
nbreg number_unlawfulaid c.district_average ///
government_position pre_election gdp_percapita_lag log_years_eu i.member_state number_totalaid, vce(cluster country_brief) 
estimates store m1

************ Hypothesis 2 and 3: 			 
*(Model 9 in comparing model.do)
* Model 3: District magnitude x Ballot control + District magnitude x VotePool_avg  (ar1)
nbreg number_unlawfulaid c.district_average i.ballot_control c.district_average#i.ballot_control c.votepool_avg c.district_average#c.votepool_avg ///
government_position pre_election gdp_percapita_lag log_years_eu i.member_state number_totalaid, vce(cluster country_brief)
estimates store m2

* Model 5: District magnitude x Ballot control + District magnitude x VotePool_sum  (ar1)
nbreg number_unlawfulaid c.district_average i.ballot_control c.district_average#i.ballot_control c.votepool_sum c.district_average#c.votepool_sum ///
government_position pre_election gdp_percapita_lag log_years_eu i.member_state number_totalaid, vce(cluster country_brief)
estimates store m3

* Note: the dispersion parameter, alpha, closely approximates zero in these models.
* When alpha is equal to zero, the negative binomial distribution is equivalent to a Poisson distribution.

outreg2 [m1 m2 m3] using Table_A3.xml, excel replace ///
title("TABLE A3: Robustness tests of Table 1 models, number unlawful aid measures as dependent variable") ///
addnote("Coefficients and standard errors, in parentheses, multiplied by 100") ///
stats(coef se) stnum(replace coef=coef*100, replace se=se*100) addstat(Wald chi2, e(chi2), Log-likelihood, e(ll), lnalpha, ln(e(alpha))) ///
keep(district_average 1.ballot_control 1.ballot_control#c.district_average votepool_avg c.district_average#c.votepool_avg votepool_sum c.district_average#c.votepool_sum government_position pre_election gdp_percapita_lag log_years_eu number_totalaid) ///
sortvar(district_average 1.ballot_control 1.ballot_control#c.district_average votepool_avg c.district_average#c.votepool_avg votepool_sum c.district_average#c.votepool_sum pre_election government_position log_years_eu gdp_percapita_lag number_totalaid)

